<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0"
	xmlns:o="http://mindcrime-ilab/2012/order-example" xmlns:i18n="http://mindcrime-ilab/2012/order-example/i18n"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	exclude-result-prefixes="o xsl i18n">
	<xsl:param name="resPathPrefix" select="string('../i18n')"></xsl:param>
	<xsl:param name="lang" select="string('en')" />
	<!-- locale defines the file containing the localisation entries -->
	<xsl:variable name="locale">
		<!-- test if there is a localisation file for given locale, otherwise use default -->
		<xsl:choose>
			<xsl:when
				test="document(concat($resPathPrefix,'/resources_',$lang,'.xml'))">
				<!-- localisation file exists -->
				<xsl:value-of select="concat($resPathPrefix,'/resources_',$lang,'.xml')" />
			</xsl:when>
			<xsl:otherwise>
				<!-- localisation file does not exist; use default eg. English locale -->
				<xsl:value-of select="concat($resPathPrefix,'/resources_en.xml')" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	
	<!-- initialize variable containing all localised strings -->
	<xsl:variable name="labels" select="document($locale)/i18n:labels" />

	<xsl:template match="/">
		<html>
			<body>
				<xsl:apply-templates select="o:order" />
				<xsl:if test="not(o:order)">
					<p>No orders placed!</p>
				</xsl:if>
			</body>
		</html>
	</xsl:template>

	<xsl:template match="o:order">
		<h>
			<xsl:value-of select="$labels/i18n:label[@id='order.recipient']" />
		</h>
		<table style="border:0px;">
			<tr>
				<th>
					<xsl:value-of select="$labels/i18n:label[@id='order.recipient.name']" />
				</th>
				<td>
					<xsl:value-of select="o:recipient/o:name" />
				</td>
			</tr>
			<tr>
				<th>
					<xsl:value-of select="$labels/i18n:label[@id='order.recipient.forename']" />
				</th>
				<td>
					<xsl:value-of select="o:recipient/o:forename" />
				</td>
			</tr>
		</table>
	</xsl:template>
</xsl:stylesheet>